@@ -94,7 +94,7 @@ def prepare_test(production_name, job_name, dependent_input=None):
     # i.e. there are no dependent jobs that need to be run first
     dynamic_dir, out_dir = create_output_dir(production_name, require_cmt)
 
-    if "turbo" in job_data:
+    if "turbo" in job_data and job_data["turbo"]:
         params["turbo"] = job_data["turbo"]
 
     if "root_in_tes" in job_data:
